﻿/// http://justinw.cnblogs.com
/// Mail:xiaoliang.justin@gmail.com
/// MSN:xiaoliang203@hotmail.com
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

namespace Justin.UILibrary
{
    /// <summary>
    /// 用于UI批量转换数据的通用方法
    /// </summary>
    public class FormConvertUtils
    {
        public FormConvertUtils()
        {
            //
            // TODO: 在此处添加构造函数逻辑
            //
        }

        #region UI2Data

        /// <summary>
        /// 将UI数据统一收集的Hashtable中。
        /// 
        /// 注释：1.简单演示以Hashtable来转换数据，实际应用中可以使用表示数据实体的实体对象。
        ///       2.这里有个局限就是如果UI上面摆放了新的控件，则需要修改代码。
        /// </summary>
        public static void UI2Data(Object obj, Hashtable ht)
        {
            foreach (Control c in (obj as System.Web.UI.Control).Controls)
            {
                if (c is TextBox)
                {
                    ht.Add(c.ID, (c as TextBox).Text);
                }
                else if (c is DropDownList)
                {
                    ht.Add(c.ID, (c as DropDownList).SelectedValue.ToString());
                }
                else if (c is HtmlTextArea)
                {
                    ht.Add(c.ID, (c as HtmlTextArea).Value);
                }
                UI2Data(c, ht);
            }
        }

        #endregion

        #region Data2UI

        /// <summary>
        /// 将Hashtable中的数据统一初始化到UI上面。
        /// 
        /// 注释：1.简单演示以Hashtable来转换数据，实际应用中可以使用表示数据实体的实体对象。
        ///       2.这里有个局限就是如果UI上面摆放了新的控件，则需要修改代码。
        /// </summary>
        public static void Data2UI(Object obj, Hashtable ht)
        {
            string key = string.Empty;
            string value = string.Empty;

            foreach (Control c in (obj as System.Web.UI.Control).Controls)
            {
                if ((c.ID != null) && (ht.ContainsKey(c.ID)))
                {
                    key = c.ID;
                    value = ht[c.ID].ToString();

                    if (c is TextBox)
                    {
                        (c as TextBox).Text = value;
                    }
                    else if (c is DropDownList)
                    {
                        (c as DropDownList).SelectedValue = value;
                    }
                    else if (c is HtmlTextArea)
                    {
                        (c as HtmlTextArea).Value = value;
                    }
                }
                Data2UI(c, ht);
            }
        }

        #endregion

        #region InitForm

        /// <summary>
        /// 初始化UI上所有下拉框。
        /// </summary>
        /// <param name="ht">key:ID;value:String[]</param>
        public static void InitDropDownList(Object obj, Hashtable ht)
        {
            foreach (Control c in (obj as System.Web.UI.Control).Controls)
            {
                if (c is DropDownList)
                {
                    if (ht.ContainsKey(c.ID))
                    {
                        (c as DropDownList).DataSource = (string[])ht[c.ID];
                        (c as DropDownList).DataBind();
                    }
                }

                InitDropDownList(c, ht);
            }
        }

        #endregion

        #region InitUIControl

        /// <summary>
        /// 批量设置UI的控件为可用/不可用，以根据UI的状态来改变输入控件的可用性。
        /// </summary>
        public static void InitUIControl(Object obj, bool sign)
        {
            foreach (Control c in (obj as System.Web.UI.Control).Controls)
            {
                if (c is TextBox)
                {
                    (c as TextBox).Enabled = sign;
                }
                else if (c is DropDownList)
                {
                    (c as DropDownList).Enabled = sign;
                }
                else if (c is HtmlTextArea)
                {
                    (c as HtmlTextArea).Disabled = !sign;
                }
                else if (c is Button)
                {
                    (c as Button).Visible = sign;
                }
                else if (c is Label)
                {
                    (c as Label).Enabled = sign;
                }
            }
        }

        #endregion
    }
}